<?php
namespace Teknisa\FIS\Services;

use DateTime;
use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Fis91000RelacaoFuncionariosEmpresaService {

    protected $nrorg;
    protected $operador;
    protected $currentTime;
    protected $environment;
    protected $entityManager;
    protected $dataSourceManager;

    public function __construct(Environment $environment, EntityManager $entityManager, $dataSourceManager) {
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->dataSourceManager = $dataSourceManager;
        $this->nrorg       = $this->environment->getNrOrg();
        $this->operador    = $this->environment->getCdOperador();
        $this->currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
    }
    
    
    public function relacionarFuncionariosVinculosEmpresa($row) {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $conditions     = $this->condicaoRelacionamento($row);
            $resultadoBanco = $this->buscar($conditions,'relacfuncempr');
            
            //Verifica se já existem relacionamento na tabela RELACFUNCEMPR
            // para ver se será nescessário inserir ou atualizar
            if( empty ($resultadoBanco->getRows() ) )
                $row['__is_new'] = true;
            else {
                $qtdFuncionarios = $row['QTFUNCIONARIO'];
                $row = $resultadoBanco->getRows()[0];
                
                $row['QTFUNCIONARIO'] = $qtdFuncionarios;
                $row['__is_new']      = false;
                
            }
            	
            $this->setCamposAuditoria($row);
            $dataSet = new DataSet('relacfuncempr', [$row]);
            $this->dataSourceManager->persist($dataSet);
            $this->entityManager->flush();
            $connection->commit();
	}
	
	
	public function condicaoRelacionamento($row) {
        $conditions = array(
            array(
                "value" => $this->nrorg,
                "operator" => "=",
                "columnName" => "NRORG"
            ),
            array(
                "value" => $row['CDEMPRESA'],
                "operator" => "=",
                "columnName" => "CDEMPRESA"
            ),
            array(
                "value" => $row['NRTIPOVINCULOH'],
                "operator" => "=",
                "columnName" => "NRTIPOVINCULOH"
            ),
            array(
                "value" => $row['DTCOMPETENCIA'],
                "operator" => "=",
                "columnName" => "DTCOMPETENCIA"
            )
        );
        return $conditions;
    }

	
    public function buscar($conditions, $dataSourceName){
        $filterCriteria = new FilterCriteria($dataSourceName,$conditions);
        return  $this->dataSourceManager->findBy($filterCriteria);
    }
    
    
    private function setCamposAuditoria ($row){
        if($row['__is_new']){
            $row['NRORG']          = $this->nrorg;
            $row['IDATIVO']        = 'S';
            $row['DTINCLUSAO']     = $this->currentTime;
            $row['DTULTATU']       = $this->currentTime;
            $row['NRORGINCLUSAO']  = $this->nrorg;
            $row['CDOPERINCLUSAO'] = $this->operador;
            $row['NRORGULTATU']    = $this->nrorg;
            $row['CDOPERULTATU']   = $this->operador;
        }else{
            $row['DTULTATU']       = $this->currentTime;
            $row['NRORGULTATU']    = $this->nrorg;
            $row['CDOPERULTATU']   = $this->operador;    
        }
    }


}